==> immersiveoverlays-1.4.4%2B1.21.10-fabric-sources.jar: cc/cassian/immersiveoverlays/ModClient.java <==
package cc.cassian.immersiveoverlays;


import cc.cassian.immersiveoverlays.config.ModConfig;
import net.minecraft.class_2960;
import net.minecraft.class_304;
import net.minecraft.class_3675;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class ModClient {
    public static final String MOD_ID = "immersiveoverlays";
    public static final String MOD_NAME = "Immersive Overlays";
    public static final Logger LOGGER = LogManager.getLogger(MOD_NAME);
    public static final int CONFIG_VERSION = 2;
    public static String loader;

    //? if >1.21.8 {
    public static final class_304.class_11900 CATEGORY = class_304.class_11900.method_74698(locate("keybinds")); // The category translation key used to categorize in the Controls screen
    //?} else {
    /*public static final String CATEGORY = "key.category.immersiveoverlays.keybinds";
     *///?}

    // A key mapping with keyboard as the default
    public static final class_304 overlayToggle = new class_304(
            "key.immersiveoverlays.toggle", // The translation key of the name shown in the Controls screen
            class_3675.class_307.field_1668, // This key mapping is for Keyboards by default
            class_3675.field_16237.method_1444(), // The default keycode
            CATEGORY
    );

    public static void init(String loader) {
        ModConfig.load();
        ModClient.loader = loader;
    }

    public static class_2960 locate(String s) {
        return locate(MOD_ID, s);
    }

    public static class_2960 locate(String namespace, String path) {
        //? if >1.21 {
        return class_2960.method_60655(namespace, path);
         //?} else {
        /*return new ResourceLocation(namespace, path);
        *///?}
    }
}

==> immersiveoverlays-1.4.5%2B1.20.6-fabric-sources.jar: cc/cassian/immersiveoverlays/ModClient.java <==
package cc.cassian.immersiveoverlays;


import cc.cassian.immersiveoverlays.config.ModConfig;
import net.minecraft.class_2960;
import net.minecraft.class_304;
import net.minecraft.class_3675;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class ModClient {
    public static final String MOD_ID = "immersiveoverlays";
    public static final String MOD_NAME = "Immersive Overlays";
    public static final Logger LOGGER = LogManager.getLogger(MOD_NAME);
    public static final int CONFIG_VERSION = 3;
    public static String loader;

    //? if >1.21.8 {
    /*public static final KeyMapping.Category CATEGORY = KeyMapping.Category.register(locate("keybinds")); // The category translation key used to categorize in the Controls screen
    *///?} else {
    public static final String CATEGORY = "key.category.immersiveoverlays.keybinds";
     //?}

    // A key mapping with keyboard as the default
    public static final class_304 overlayToggle = new class_304(
            "key.immersiveoverlays.toggle", // The translation key of the name shown in the Controls screen
            class_3675.class_307.field_1668, // This key mapping is for Keyboards by default
            class_3675.field_16237.method_1444(), // The default keycode
            CATEGORY
    );

    public static void init(String loader) {
        ModConfig.load();
        ModClient.loader = loader;
    }

    public static class_2960 locate(String s) {
        return locate(MOD_ID, s);
    }

    public static class_2960 locate(String namespace, String path) {
        //? if >1.21 {
        /*return ResourceLocation.fromNamespaceAndPath(namespace, path);
         *///?} else {
        return new class_2960(namespace, path);
        //?}
    }
}
